==> jc-1.4.0.tar.gz: javax/security/auth/callback/UnsupportedCallbackException.h <==
// public class javax.security.auth.callback.UnsupportedCallbackException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 3687139e9dcd50a0 javax_security_auth_callback_UnsupportedCallbackException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_security_auth_callback_UnsupportedCallbackException_H_
#define _JC_javax_security_auth_callback_UnsupportedCallbackException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_security_auth_callback_Callback$object;

// Typedefs
typedef struct _jc_javax_security_auth_callback_UnsupportedCallbackException$sub_refs	_jc_javax_security_auth_callback_UnsupportedCallbackException$sub_refs;
typedef struct _jc_javax_security_auth_callback_UnsupportedCallbackException$sub_nonrefs	_jc_javax_security_auth_callback_UnsupportedCallbackException$sub_nonrefs;
typedef struct _jc_javax_security_auth_callback_UnsupportedCallbackException$refs	_jc_javax_security_auth_callback_UnsupportedCallbackException$refs;
typedef struct _jc_javax_security_auth_callback_UnsupportedCallbackException$nonrefs	_jc_javax_security_auth_callback_UnsupportedCallbackException$nonrefs;
typedef struct _jc_javax_security_auth_callback_UnsupportedCallbackException$object	_jc_javax_security_auth_callback_UnsupportedCallbackException$object;

typedef const struct _jc_javax_security_auth_callback_UnsupportedCallbackException$vmethods	_jc_javax_security_auth_callback_UnsupportedCallbackException$vmethods;
typedef const struct _jc_javax_security_auth_callback_UnsupportedCallbackException$vtable	_jc_javax_security_auth_callback_UnsupportedCallbackException$vtable;
typedef const struct _jc_javax_security_auth_callback_UnsupportedCallbackException$vtype	_jc_javax_security_auth_callback_UnsupportedCallbackException$vtype;

// Constructors
extern void _jc_javax_security_auth_callback_UnsupportedCallbackException$method$_init$d52e6288b04080b4(_jc_env *, struct _jc_javax_security_auth_callback_UnsupportedCallbackException$object *, struct _jc_object *);
extern void _jc_javax_security_auth_callback_UnsupportedCallbackException$method$_init$68456591ac68a531(_jc_env *, struct _jc_javax_security_auth_callback_UnsupportedCallbackException$object *, struct _jc_object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_object *_jc_javax_security_auth_callback_UnsupportedCallbackException$method$getCallback$91d6c973771868a2(_jc_env *, struct _jc_javax_security_auth_callback_UnsupportedCallbackException$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_callback_UnsupportedCallbackException$method_info$getCallback$91d6c973771868a2;

// Virtual methods structure
struct _jc_javax_security_auth_callback_UnsupportedCallbackException$vmethods {
	struct _jc_object	*(*getCallback$91d6c973771868a2)(_jc_env *, struct _jc_javax_security_auth_callback_UnsupportedCallbackException$object *);
};

// Vtable
struct _jc_javax_security_auth_callback_UnsupportedCallbackException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_security_auth_callback_UnsupportedCallbackException$vmethods	javax_security_auth_callback_UnsupportedCallbackException;
};

// Vtype
struct _jc_javax_security_auth_callback_UnsupportedCallbackException$vtype {
	_jc_type			type;
	_jc_javax_security_auth_callback_UnsupportedCallbackException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_callback_UnsupportedCallbackException$sub_refs {
	struct _jc_object	*callback;
};

// Reference instance fields (object)
struct _jc_javax_security_auth_callback_UnsupportedCallbackException$refs {
    _jc_javax_security_auth_callback_UnsupportedCallbackException$sub_refs	javax_security_auth_callback_UnsupportedCallbackException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_callback_UnsupportedCallbackException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_callback_UnsupportedCallbackException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_security_auth_callback_UnsupportedCallbackException$sub_nonrefs	javax_security_auth_callback_UnsupportedCallbackException;
};

// Object instance structure
struct _jc_javax_security_auth_callback_UnsupportedCallbackException$object {
	_jc_javax_security_auth_callback_UnsupportedCallbackException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_callback_UnsupportedCallbackException$vtype	*vtype;
	_jc_javax_security_auth_callback_UnsupportedCallbackException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_callback_UnsupportedCallbackException$vtype _jc_javax_security_auth_callback_UnsupportedCallbackException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_callback_UnsupportedCallbackException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_callback_UnsupportedCallbackException$class_object;

#endif	/* _JC_javax_security_auth_callback_UnsupportedCallbackException_H_ */

==> jc-1.4.6.tar.gz: javax/security/auth/callback/UnsupportedCallbackException.h <==
// public class javax.security.auth.callback.UnsupportedCallbackException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 3687139e9dcd50a0 javax_security_auth_callback_UnsupportedCallbackException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_security_auth_callback_UnsupportedCallbackException_H_
#define _JC_javax_security_auth_callback_UnsupportedCallbackException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_security_auth_callback_Callback$object;

// Typedefs
typedef struct _jc_javax_security_auth_callback_UnsupportedCallbackException$sub_refs	_jc_javax_security_auth_callback_UnsupportedCallbackException$sub_refs;
typedef struct _jc_javax_security_auth_callback_UnsupportedCallbackException$sub_nonrefs	_jc_javax_security_auth_callback_UnsupportedCallbackException$sub_nonrefs;
typedef struct _jc_javax_security_auth_callback_UnsupportedCallbackException$refs	_jc_javax_security_auth_callback_UnsupportedCallbackException$refs;
typedef struct _jc_javax_security_auth_callback_UnsupportedCallbackException$nonrefs	_jc_javax_security_auth_callback_UnsupportedCallbackException$nonrefs;
typedef struct _jc_javax_security_auth_callback_UnsupportedCallbackException$object	_jc_javax_security_auth_callback_UnsupportedCallbackException$object;

typedef const struct _jc_javax_security_auth_callback_UnsupportedCallbackException$vmethods	_jc_javax_security_auth_callback_UnsupportedCallbackException$vmethods;
typedef const struct _jc_javax_security_auth_callback_UnsupportedCallbackException$vtable	_jc_javax_security_auth_callback_UnsupportedCallbackException$vtable;
typedef const struct _jc_javax_security_auth_callback_UnsupportedCallbackException$vtype	_jc_javax_security_auth_callback_UnsupportedCallbackException$vtype;

// Constructors
extern void _jc_javax_security_auth_callback_UnsupportedCallbackException$method$_init$d52e6288b04080b4(_jc_env *, struct _jc_javax_security_auth_callback_UnsupportedCallbackException$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_auth_callback_UnsupportedCallbackException$method$_init$68456591ac68a531(_jc_env *, struct _jc_javax_security_auth_callback_UnsupportedCallbackException$object *, struct _jc_object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_security_auth_callback_UnsupportedCallbackException$method$getCallback$91d6c973771868a2(_jc_env *, struct _jc_javax_security_auth_callback_UnsupportedCallbackException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_callback_UnsupportedCallbackException$method_info$getCallback$91d6c973771868a2;

// Virtual methods structure
struct _jc_javax_security_auth_callback_UnsupportedCallbackException$vmethods {
	struct _jc_object	*(*getCallback$91d6c973771868a2)(_jc_env *, struct _jc_javax_security_auth_callback_UnsupportedCallbackException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_security_auth_callback_UnsupportedCallbackException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_security_auth_callback_UnsupportedCallbackException$vmethods	javax_security_auth_callback_UnsupportedCallbackException;
};

// Vtype
struct _jc_javax_security_auth_callback_UnsupportedCallbackException$vtype {
	_jc_type			type;
	_jc_javax_security_auth_callback_UnsupportedCallbackException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_callback_UnsupportedCallbackException$sub_refs {
	struct _jc_object	*callback;
};

// Reference instance fields (object)
struct _jc_javax_security_auth_callback_UnsupportedCallbackException$refs {
    _jc_javax_security_auth_callback_UnsupportedCallbackException$sub_refs	javax_security_auth_callback_UnsupportedCallbackException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_callback_UnsupportedCallbackException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_callback_UnsupportedCallbackException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_security_auth_callback_UnsupportedCallbackException$sub_nonrefs	javax_security_auth_callback_UnsupportedCallbackException;
};

// Object instance structure
struct _jc_javax_security_auth_callback_UnsupportedCallbackException$object {
	_jc_javax_security_auth_callback_UnsupportedCallbackException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_callback_UnsupportedCallbackException$vtype	*vtype;
	_jc_javax_security_auth_callback_UnsupportedCallbackException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_callback_UnsupportedCallbackException$vtype _jc_javax_security_auth_callback_UnsupportedCallbackException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_callback_UnsupportedCallbackException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_callback_UnsupportedCallbackException$class_object;

#endif	/* _JC_javax_security_auth_callback_UnsupportedCallbackException_H_ */
